<?php
/**
 * Stripe add-on for Events Manager Pro 
 *
 * An addon for the Events Manager Pro plugin that provides a gateway for Stripe
 *
 * @package   Events_Manager_Stripe
 * @author    Sam De Francesco <sam@defrances.co>
 * @license   GPL-2.0+
 * @link      http://code.defrances.co/projects/em-stripe
 * @copyright 2013 Sam De Francesco
 *
 * @wordpress-plugin
 * Plugin Name: Events Manager Pro Stripe Gateway
 * Plugin URI:  http://code.defrances.co/projects/em-stripe
 * Description: A Stripe Gateway add-on for the Event Manager Pro plugin
 * Version:     1.0.0
 * Author:      Sam De Francesco <sam@defrances.co>
 * Author URI:  http://defrances.co/
 * Text Domain: events-manager-stripe-locale
 * Donate link: https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=B3HQNRHL23FQW
 * License:     GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 * Domain Path: /lang
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/* initialise plugin once other plugins are loaded *//* Anonymous functions require >= PHP 5.3  */
add_action( 'plugins_loaded', function() {
    //check that EM Pro is installed
    if( ! defined( 'EMP_VERSION' ) ) {
        add_action('admin_notices', function() {
            ?> <div class="error"><p><?php _e('Please ensure you have <a href="http://eventsmanagerpro.com/">Events Manager Pro</a>
                                               installed, as this is a requirement for the Stripe add-on.','events-manager-stripe'); ?></p></div>
            <?php
        } );
        return false; //don't load plugin further
    }

    require_once( plugin_dir_path( __FILE__ ) . 'class-events-manager-stripe.php' );
    EM_Gateways::register_gateway('stripe', 'EM_Gateway_Stripe');

});

/**
 * Settings link in the plugins page menu
 */
add_filter( 'plugin_action_links_events-manager-stripe/events-manager-stripe.php', function($actions, $file, $plugin_data) {
    $new_actions = array();
    $new_actions[] = sprintf( '<a href="'.EM_ADMIN_URL.'&amp;page=events-manager-gateways&amp;action=edit&amp;gateway=stripe">%s</a>', __('Settings', 'dbem') );
    $new_actions[] = sprintf( '<a href="https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&amp;hosted_button_id=B3HQNRHL23FQW">%s</a>', __('Donate', 'dbem') );
    $new_actions = array_merge($new_actions, $actions);
    return $new_actions;
}, 10, 3 );

/* eof */
